pub trait ValueEnum {
// Required method
fn as_enum_str(&self) -> Result<Cow<'static, str>, PlanError>;
}Expand description
A trait for enum types that can be rendered as &VariantName in the text
format.
pub trait ValueEnum {
// Required method
fn as_enum_str(&self) -> Result<Cow<'static, str>, PlanError>;
}A trait for enum types that can be rendered as &VariantName in the text
format.